<!DOCTYPE html><html><head><link rel="modulepreload" href="/frontend_latest/core.bd2c149f.js" crossorigin="use-credentials"><link rel="modulepreload" href="/frontend_latest/app.d577e21d.js" crossorigin="use-credentials"><meta charset="utf-8"><link rel="manifest" href="/manifest.json" crossorigin="use-credentials"><link rel="icon" href="/static/icons/favicon.ico"><meta name="viewport" content="width=device-width,user-scalable=no,viewport-fit=cover"><style>body{font-family:Roboto,sans-serif;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-weight:400;margin:0;padding:0;height:100%}</style><title>Home Assistant</title><link rel="mask-icon" href="/static/icons/mask-icon.svg" color="#03a9f4"><link rel="apple-touch-icon" sizes="180x180" href="/static/icons/favicon-apple-180x180.png"><meta name="apple-itunes-app" content="app-id=1099568401"><meta name="apple-mobile-web-app-capable" content="yes"><meta name="apple-mobile-web-app-status-bar-style" content="default"><meta name="apple-mobile-web-app-title" content="Home Assistant"><meta name="msapplication-square70x70logo" content="/static/icons/tile-win-70x70.png"><meta name="msapplication-square150x150logo" content="/static/icons/tile-win-150x150.png"><meta name="msapplication-wide310x150logo" content="/static/icons/tile-win-310x150.png"><meta name="msapplication-square310x310logo" content="/static/icons/tile-win-310x310.png"><meta name="msapplication-TileColor" content="#03a9f4ff"><meta name="mobile-web-app-capable" content="yes"><meta name="referrer" content="same-origin"><meta name="theme-color" content="{{ theme_color }}"><meta name="color-scheme" content="dark light"><style>#ha-init-skeleton::before{display:block;content:"";height:56px;background-color:{{ theme_color }}}html{background-color:var(--primary-background-color)}@media (prefers-color-scheme:dark){html{background-color:#111;color:#e1e1e1}#ha-init-skeleton::before{background-color:#1c1c1c}}</style></head><body><div id="ha-init-skeleton"></div><home-assistant></home-assistant><script>function _ls(e){var t=document.documentElement,n=t.insertBefore(document.createElement("script"),t.lastChild);return n.defer=!0,n.src=e,n}window.Polymer={lazyRegister:!0,useNativeCSSProperties:!0,dom:"shadow",suppressTemplateNotifications:!0,suppressBindingNotifications:!0},"customElements"in window&&"content"in document.createElement("template")||document.write("<script src='/static/polyfills/webcomponents-bundle.js'><\/script>")</script><script>function _pf(o,t){var n=document.createElement("link");n.rel="preload",n.as="font",n.type="font/woff2",n.href=o,n.crossOrigin="anonymous",document.head.appendChild(n)}-1===navigator.userAgent.indexOf("Android")&&-1===navigator.userAgent.indexOf("CrOS")&&(_pf("/static/fonts/roboto/Roboto-Regular.woff2"),_pf("/static/fonts/roboto/Roboto-Medium.woff2"))</script><script crossorigin="use-credentials">import("/frontend_latest/core.bd2c149f.js"),import("/frontend_latest/app.d577e21d.js"),window.customPanelJS="/frontend_latest/custom-panel.68fdae13.js",window.latestJS=!0</script><script>{% for extra_module in extra_modules -%}
    import("{{ extra_module }}");
    {% endfor -%}</script><script>window.latestJS||(window.customPanelJS="/frontend_es5/custom-panel.7b5c6c0b.js",_ls("/frontend_es5/core.6f1c9cf5.js"),_ls("/frontend_es5/app.85ace790.js"))</script><script>if (!window.latestJS) {
        {% for extra_script in extra_js_es5 -%}
        _ls("{{ extra_script }}");
        {% endfor -%}
      }</script></body></html>