(self.webpackChunkhome_assistant_frontend=self.webpackChunkhome_assistant_frontend||[]).push([[5859],{65859:(e,a,n)=>{"use strict";n.r(a);var l=n(9850);l.tsParticles.load("particles",{fullScreen:{enable:!0,zIndex:-1},detectRetina:!0,fpsLimit:60,motion:{disable:!1,reduce:{factor:4,value:!0}},particles:{color:{value:"#fff",animation:{enable:!0,speed:50,sync:!1}},links:{color:{value:"random"},distance:100,enable:!0,frequency:1,opacity:.7,width:1},move:{enable:!0,speed:.5},number:{density:{enable:!0,area:800,factor:1e3},limit:0,value:50},opacity:{random:{enable:!0,minimumValue:.3},value:.5,animation:{destroy:"none",enable:!0,minimumValue:.3,speed:.5,startValue:"random",sync:!1}},size:{random:{enable:!0,minimumValue:1},value:3,animation:{destroy:"none",enable:!0,minimumValue:1,speed:3,startValue:"random",sync:!1}}},pauseOnBlur:!0})}}]);
//# sourceMappingURL=chunk.0bc60abd2ddfd9b0358d.js.map