(self.webpackChunkhome_assistant_frontend=self.webpackChunkhome_assistant_frontend||[]).push([[4705],{4705:function(e,t,n){"use strict";n.r(t);n(12730);var o,r=n(50856),l=n(28426);n(48932),n(3426);function a(e){return(a="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e})(e)}function c(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function u(e,t){for(var n=0;n<t.length;n++){var o=t[n];o.enumerable=o.enumerable||!1,o.configurable=!0,"value"in o&&(o.writable=!0),Object.defineProperty(e,o.key,o)}}function i(e,t){return(i=Object.setPrototypeOf||function(e,t){return e.__proto__=t,e})(e,t)}function f(e){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(e){return!1}}();return function(){var n,o=p(e);if(t){var r=p(this).constructor;n=Reflect.construct(o,arguments,r)}else n=o.apply(this,arguments);return s(this,n)}}function s(e,t){return!t||"object"!==a(t)&&"function"!=typeof t?function(e){if(void 0===e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}(e):t}function p(e){return(p=Object.setPrototypeOf?Object.getPrototypeOf:function(e){return e.__proto__||Object.getPrototypeOf(e)})(e)}var y=function(e){!function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,writable:!0,configurable:!0}}),t&&i(e,t)}(s,e);var t,n,l,a=f(s);function s(){return c(this,s),a.apply(this,arguments)}return t=s,l=[{key:"template",get:function(){return(0,r.d)(o||(e=['\n      <style include="ha-style">\n        iframe {\n          border: 0;\n          width: 100%;\n          position: absolute;\n          height: calc(100% - var(--header-height));\n          background-color: var(--primary-background-color);\n        }\n      </style>\n      <app-toolbar>\n        <ha-menu-button hass="[[hass]]" narrow="[[narrow]]"></ha-menu-button>\n        <div main-title>[[panel.title]]</div>\n      </app-toolbar>\n\n      <iframe\n        src="[[panel.config.url]]"\n        sandbox="allow-forms allow-popups allow-pointer-lock allow-same-origin allow-scripts allow-modals"\n        allowfullscreen="true"\n        webkitallowfullscreen="true"\n        mozallowfullscreen="true"\n      ></iframe>\n    '],t||(t=e.slice(0)),o=Object.freeze(Object.defineProperties(e,{raw:{value:Object.freeze(t)}}))));var e,t}},{key:"properties",get:function(){return{hass:Object,narrow:Boolean,panel:Object}}}],(n=null)&&u(t.prototype,n),l&&u(t,l),s}(l.H3);customElements.define("ha-panel-iframe",y)},3426:function(e,t,n){"use strict";n(21384);var o=n(11654),r=document.createElement("template");r.setAttribute("style","display: none;"),r.innerHTML='<dom-module id="ha-style">\n  <template>\n    <style>\n    '.concat(o.Qx.cssText,"\n    </style>\n  </template>\n</dom-module>"),document.head.appendChild(r.content)}}]);
//# sourceMappingURL=chunk.07154092bba69b95dee7.js.map